@@ -19,7 +19,6 @@ package spanner
 import (
 	"fmt"
 	"reflect"
-	"strings"
 
 	sppb "cloud.google.com/go/spanner/apiv1/spannerpb"
 	proto3 "github.com/golang/protobuf/ptypes/struct"
@@ -481,13 +480,11 @@ func SelectAll(rows rowIterator, destination interface{}, options ...DecodeOptio
 		}
 		if !isPrimitive {
 			e := sliceItem.Elem()
-			idx := 0
-			for _, p := range pointers {
+			for i, p := range pointers {
 				if p == nil {
 					continue
 				}
-				e.Field(idx).Set(reflect.ValueOf(p).Elem())
-				idx++
+				e.Field(i).Set(reflect.ValueOf(p).Elem())
 			}
 		}
 		var elemVal reflect.Value
@@ -513,13 +510,9 @@ func structPointers(sliceItem reflect.Value, cols []*sppb.StructType_Field, leni
 	fieldTag := make(map[string]reflect.Value, len(cols))
 	initFieldTag(sliceItem, &fieldTag)
 
-	for i, colName := range cols {
-		if colName.Name == "" {
-			return nil, errColNotFound(fmt.Sprintf("column %d", i))
-		}
-
+	for _, colName := range cols {
 		var fieldVal reflect.Value
-		if v, ok := fieldTag[strings.ToLower(colName.GetName())]; ok {
+		if v, ok := fieldTag[colName.GetName()]; ok {
 			fieldVal = v
 		} else {
 			if !lenient {
@@ -555,18 +548,16 @@ func initFieldTag(sliceItem reflect.Value, fieldTagMap *map[string]reflect.Value
 		}
 		if fieldType.Type.Kind() == reflect.Struct {
 			// found an embedded struct
-			if fieldType.Anonymous {
-				sliceItemOfAnonymous := sliceItem.Field(i)
-				initFieldTag(sliceItemOfAnonymous, fieldTagMap)
-				continue
-			}
+			sliceItemOfAnonymous := sliceItem.Field(i)
+			initFieldTag(sliceItemOfAnonymous, fieldTagMap)
+			continue
 		}
 		name, keep, _, _ := spannerTagParser(fieldType.Tag)
 		if !keep {
 			continue
 		}
 		if name == "" {
-			name = strings.ToLower(fieldType.Name)
+			name = fieldType.Name
 		}
 		(*fieldTagMap)[name] = sliceItem.Field(i)
 	}
