@@ -2003,10 +2003,8 @@ func TestSelectAll(t *testing.T) {
 	}
 	type testStruct struct {
 		Col1 int64
-		// declaring second column in upper case here to verify SelectAll does case-insensitive matching
-		COL2 float64
+		Col2 float64
 		Col3 string
-		Col4 time.Time
 	}
 	tests := []struct {
 		name    string
@@ -2070,26 +2068,24 @@ func TestSelectAll(t *testing.T) {
 							{Name: "Col1", Type: intType()},
 							{Name: "Col2", Type: floatType()},
 							{Name: "Col3", Type: stringType()},
-							{Name: "Col4", Type: timeType()},
 						},
-						[]*proto3.Value{intProto(1), floatProto(1.1), stringProto("value"), timeProto(tm)},
+						[]*proto3.Value{intProto(1), floatProto(1.1), stringProto("value")},
 					}, nil)
 					mockIterator.On("Next").Once().Return(&Row{
 						[]*sppb.StructType_Field{
 							{Name: "Col1", Type: intType()},
 							{Name: "Col2", Type: floatType()},
 							{Name: "Col3", Type: stringType()},
-							{Name: "Col4", Type: timeType()},
 						},
-						[]*proto3.Value{intProto(2), floatProto(2.2), stringProto("value2"), timeProto(tm.Add(24 * time.Hour))},
+						[]*proto3.Value{intProto(2), floatProto(2.2), stringProto("value2")},
 					}, nil)
 					mockIterator.On("Next").Once().Return(nil, iterator.Done)
 					mockIterator.On("Stop").Once().Return(nil)
 				},
 			},
 			want: &[]testStruct{
-				{Col1: 1, COL2: 1.1, Col3: "value", Col4: tm},
-				{Col1: 2, COL2: 2.2, Col3: "value2", Col4: tm.Add(24 * time.Hour)},
+				{Col1: 1, Col2: 1.1, Col3: "value"},
+				{Col1: 2, Col2: 2.2, Col3: "value2"},
 			},
 		},
 		{
@@ -2118,8 +2114,8 @@ func TestSelectAll(t *testing.T) {
 				},
 			},
 			want: &[]*testStruct{
-				{Col1: 1, COL2: 1.1, Col3: "value"},
-				{Col1: 2, COL2: 2.2, Col3: "value2"},
+				{Col1: 1, Col2: 1.1, Col3: "value"},
+				{Col1: 2, Col2: 2.2, Col3: "value2"},
 			}},
 		{
 			name: "success: when spanner row contains more columns than declared in Go struct but called WithLenient",
@@ -2131,10 +2127,9 @@ func TestSelectAll(t *testing.T) {
 							{Name: "Col1", Type: intType()},
 							{Name: "Col2", Type: floatType()},
 							{Name: "Col3", Type: stringType()},
-							{Name: "Col4", Type: timeType()},
-							{Name: "Col5", Type: stringType()},
+							{Name: "Col4", Type: stringType()},
 						},
-						[]*proto3.Value{intProto(1), floatProto(1.1), stringProto("value"), timeProto(tm), stringProto("value2")},
+						[]*proto3.Value{intProto(1), floatProto(1.1), stringProto("value"), stringProto("value4")},
 					}, nil)
 					// failure case
 					mockIterator.On("Next").Once().Return(nil, iterator.Done)
@@ -2143,13 +2138,13 @@ func TestSelectAll(t *testing.T) {
 				options: []DecodeOptions{WithLenient()},
 			},
 			want: &[]*testStruct{
-				{Col1: 1, COL2: 1.1, Col3: "value", Col4: tm},
+				{Col1: 1, Col2: 1.1, Col3: "value"},
 			},
 		},
 		{
 			name: "success: using prefilled destination should append to the destination",
 			args: args{
-				destination: &[]*testStruct{{Col1: 3, COL2: 3.3, Col3: "value3"}},
+				destination: &[]*testStruct{{Col1: 3, Col2: 3.3, Col3: "value3"}},
 				mock: func(mockIterator *mockRowIterator) {
 					mockIterator.On("Next").Once().Return(&Row{
 						[]*sppb.StructType_Field{
@@ -2172,14 +2167,14 @@ func TestSelectAll(t *testing.T) {
 				},
 			},
 			want: &[]*testStruct{
-				{Col1: 3, COL2: 3.3, Col3: "value3"},
-				{Col1: 1, COL2: 1.1, Col3: "value"},
-				{Col1: 2, COL2: 2.2, Col3: "value2"},
+				{Col1: 3, Col2: 3.3, Col3: "value3"},
+				{Col1: 1, Col2: 1.1, Col3: "value"},
+				{Col1: 2, Col2: 2.2, Col3: "value2"},
 			}},
 		{
 			name: "failure: in case of error destination will have the partial result",
 			args: args{
-				destination: &[]*testStruct{{Col1: 3, COL2: 3.3, Col3: "value3"}},
+				destination: &[]*testStruct{{Col1: 3, Col2: 3.3, Col3: "value3"}},
 				mock: func(mockIterator *mockRowIterator) {
 					mockIterator.On("Next").Once().Return(&Row{
 						[]*sppb.StructType_Field{
@@ -2195,15 +2190,15 @@ func TestSelectAll(t *testing.T) {
 				},
 			},
 			want: &[]*testStruct{
-				{Col1: 3, COL2: 3.3, Col3: "value3"},
-				{Col1: 1, COL2: 1.1, Col3: "value"},
+				{Col1: 3, Col2: 3.3, Col3: "value3"},
+				{Col1: 1, Col2: 1.1, Col3: "value"},
 			},
 			wantErr: true,
 		},
 		{
 			name: "failure: when spanner row contains more columns than declared in Go struct",
 			args: args{
-				destination: &[]*testStruct{{Col1: 3, COL2: 3.3, Col3: "value3"}},
+				destination: &[]*testStruct{{Col1: 3, Col2: 3.3, Col3: "value3"}},
 				mock: func(mockIterator *mockRowIterator) {
 					mockIterator.On("Next").Once().Return(&Row{
 						[]*sppb.StructType_Field{
@@ -2220,7 +2215,7 @@ func TestSelectAll(t *testing.T) {
 				},
 			},
 			want: &[]*testStruct{
-				{Col1: 3, COL2: 3.3, Col3: "value3"},
+				{Col1: 3, Col2: 3.3, Col3: "value3"},
 			},
 			wantErr: true,
 		},
